Method: ActiveFedora::Indexing::DefaultDescriptors.symbol
- Defined in:
- lib/active_fedora/indexing/default_descriptors.rb
.symbol ⇒ Object
Produces _ssim suffix This is useful for when you only want to match whole words, such as user/group names from the the rightsMetadata datastream
34 35 36 |
# File 'lib/active_fedora/indexing/default_descriptors.rb', line 34 def self.symbol @symbol ||= Descriptor.new(:string, :stored, :indexed, :multivalued) end |